@@ -15,6 +15,13 @@ class RequestHandler(object):
             self.status_code = StatusCode(200, 'Ok')
 
     def ensure_success_response(self):
+        """
+        Guarantee the success on response.
+
+        If the response is not successed, raises an
+        :class:`HttpResponseError <splinter.request_handler.status_code.HttpResponseError>`
+        exception.
+        """
         self.status_code.is_valid_response()
 
     def _store_response(self):
