@@ -24,3 +24,8 @@ class AsyncFinderTests(object):
         "should find by name found an async element"
         self.browser.find_by_css('.add-async-element').first.click()
         assert 1 == len(self.browser.find_by_name('async-input'))
+
+    def test_find_by_value_should_found_an_async_element(self):
+        "should find by value found an async element"
+        self.browser.find_by_css('.add-async-element').first.click()
+        assert 1 == len(self.browser.find_by_value('async-header-value'))
