@@ -1,4 +1,7 @@
 # -*- coding: utf-8 -*-
+
+from __future__ import with_statement
+
 from nose.tools import assert_equals, assert_true, assert_false
 
 from async_finder import AsyncFinderTests
@@ -104,3 +107,31 @@ class WebDriverTests(BaseBrowserTests, IFrameElementsTest, ElementDoestNotExistT
     def test_default_wait_time_should_be_2(self):
         "should driver default wait time 2"
         assert_equals(2, self.browser.wait_time)
+
+    def test_access_alerts_and_accept_them(self):
+        self.browser.visit(EXAMPLE_APP + 'alert')
+        self.browser.find_by_tag('h1').first.click()
+        alert = self.browser.get_alert()
+        assert_equals('This is an alert example.', alert.text)
+        alert.accept()
+
+    def test_access_prompts_and_be_able_to_fill_then(self):
+        self.browser.visit(EXAMPLE_APP + 'alert')
+        self.browser.find_by_tag('h2').first.click()
+
+        alert = self.browser.get_alert()
+        assert_equals('What is your name?', alert.text)
+        alert.fill_with('Splinter')
+        alert.accept()
+
+        response = self.browser.get_alert()
+        assert_equals('Splinter', response.text)
+        response.accept()
+
+    def test_access_alerts_using_with(self):
+        "should access alerts using 'with' statement"
+        self.browser.visit(EXAMPLE_APP + 'alert')
+        self.browser.find_by_tag('h1').first.click()
+        with self.browser.get_alert() as alert:
+            assert_equals('This is an alert example.', alert.text)
+            alert.accept()
