@@ -22,6 +22,15 @@ class CookiesTest(object):
         self.browser.cookies.delete('cookie')
         assert_equals(self.browser.cookies, {})
 
+    def test_create_and_delete_many_cookies(self):
+        "should be able to create and destroy many cookies"
+        self.browser.cookies.delete()
+        self.browser.cookies.add({'cookie': 'cooked'})
+        self.browser.cookies.add({'anothercookie': 'uncooked'})
+        self.browser.cookies.add({'notacookie': 'halfcooked'})
+        self.browser.cookies.delete('cookie', 'notacookie')
+        assert_equals('uncooked', self.browser.cookies['anothercookie'])
+
     def test_try_to_destroy_an_absent_cookie_and_nothing_happens(self):
         self.browser.cookies.delete()
         self.browser.cookies.add({'foo': 'bar'})
