@@ -9,9 +9,38 @@ EXAMPLE_HTML = """\
 <html>
   <head>
     <title>Example Title</title>
+    <style>
+        .draggable {
+            display: block;
+            background-color: #0000ff;
+            width: 100px;
+            height: 30px;
+        }
+
+        .droppable {
+            display: block;
+            background-color: #ccc;
+            width: 200px;
+            height: 50px;
+        }
+    </style>
     <script type="text/javascript" src="/static/jquery.min.js"></script>
+    <script type="text/javascript" src="/static/jquery-ui-1.8.16.custom.min.js"></script>
     <script type="text/javascript">
         $(document).ready(function() {
+            $(".draggable").draggable();
+            $(".droppable").droppable({
+                drop: function() {
+                    $('.dragged').html('yes');
+                }
+            });
+            $("body").dblclick(function(){
+                $("body").css("background-color", "#ff0000");
+            });
+            $(".should-be-visible-after-double-click").hide();
+            $(".db-button").dblclick(function(){
+                $(".should-be-visible-after-double-click").show();
+            });
            $(".add-async-element").click(function() {
                 setTimeout(function() {
                     $('body').append('<h4 id="async-header" value="async-header-value" class="async-element">async elment</h4>');
@@ -23,6 +52,10 @@ EXAMPLE_HTML = """\
                 }, 2400 );
            });
 
+           $('.right-clicable').bind('contextmenu', function(){
+                $(this).html('right clicked');
+           });
+
            $(".remove-async-element").click(function() {
                 setTimeout(function() {
                     $('.async-element').remove();
@@ -85,6 +118,12 @@ EXAMPLE_HTML = """\
             <input id="visible" name="upload" type="text" value="crazy diamond" />
         </form>
     </div>
+    <a href="#" class="db-button">double click button</a>
+    <div class="should-be-visible-after-double-click">should-be-visible-after-double-click</div>
+    <div class="right-clicable">no right click</div>
+    <div class='draggable'>draggable</div>
+    <div class='droppable'>droppable</div>
+    <div class='dragged'>no</div>
   </body>
 </html>"""
 
@@ -237,3 +276,5 @@ def stop_server():
     env.process.terminate()
     wait_until_stop()
 
+if __name__ == '__main__':
+    app.run()
