@@ -1,3 +1,7 @@
+# -*- coding: utf-8 -*-
+
+from __future__ import with_statement
+
 from nose.tools import assert_equals
 
 
