@@ -4,11 +4,12 @@ from fake_webapp import EXAMPLE_APP
 from base import WebDriverTests
 from nose.tools import raises
 
+
 class ChromeBrowserTest(WebDriverTests, unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        cls.browser = Browser('webdriver.chrome')
+        cls.browser = Browser('chrome')
 
     def setUp(self):
         self.browser.visit(EXAMPLE_APP)
@@ -19,5 +20,5 @@ class ChromeBrowserTest(WebDriverTests, unittest.TestCase):
 
     @raises(NotImplementedError)
     def test_attach_file_is_not_implemented(self):
-        "attach file is no implemented for chrome driver"
-        self.browser.attach_file('file', 'file_paht')
+        "attach file is not implemented for chrome driver"
+        self.browser.attach_file('file', 'file_path')
